pub struct ResetForm {
pub email: String,
pub token: String,
pub password: String,
pub password_confirmation: String,
pub csrf: Option<String>,
}Fields
email: Stringtoken: Stringpassword: Stringpassword_confirmation: Stringcsrf: Option<String>Implementations
Sourceimpl ResetForm
impl ResetForm
Sourceimpl ResetForm
impl ResetForm
Sourcepub fn validate<__VldT: Serialize>(instance: &__VldT) -> Result<(), VldError>
pub fn validate<__VldT: Serialize>(instance: &__VldT) -> Result<(), VldError>
Validate an existing Rust value that can be serialized to JSON.
The value is serialized via serde, then validated against the
schema. Returns Ok(()) on success, Err(VldError) with all
issues on failure.
Requires the serialize feature.
Sourceimpl ResetForm
impl ResetForm
Sourcepub fn json_schema() -> Value
pub fn json_schema() -> Value
Generate a JSON Schema / OpenAPI 3.1 representation of this struct.
Requires the openapi feature.
Sourcepub fn to_openapi_document() -> Value
pub fn to_openapi_document() -> Value
Wrap json_schema() in a minimal OpenAPI 3.1 document.
Requires the openapi feature.